"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StartBinaryFailedError = exports.Md5CheckFailedError = exports.NoSystemBinaryFoundError = exports.EnsureInstanceError = exports.WaitForPrimaryTimeoutError = exports.UnknownArchitectureError = exports.UnknownPlatformError = exports.UnableToUnlockLockfileError = exports.UnknownLockfileStatusError = exports.StateError = void 0;
const utils_1 = require("./utils");
class StateError extends Error {
    constructor(wantedStates, gotState) {
        super(`Incorrect State for operation: "${gotState}", allowed States: "[${wantedStates.join(',')}]"\n` +
            'This may be because of using a v6.x way of calling functions, look at the following guide if anything applies:\n' +
            'https://nodkz.github.io/mongodb-memory-server/docs/guides/migrate7#no-function-other-than-start-create-ensureinstance-will-be-starting-anything');
        this.wantedStates = wantedStates;
        this.gotState = gotState;
    }
}
exports.StateError = StateError;
class UnknownLockfileStatusError extends Error {
    constructor(status) {
        super(`Unknown LockFile Status: "${status}"`);
        this.status = status;
    }
}
exports.UnknownLockfileStatusError = UnknownLockfileStatusError;
class UnableToUnlockLockfileError extends Error {
    constructor(thisInstance, file) {
        super(`Cannot unlock file "${file}", because it is not locked by this ${thisInstance ? 'instance' : 'process'}`);
        this.thisInstance = thisInstance;
        this.file = file;
    }
}
exports.UnableToUnlockLockfileError = UnableToUnlockLockfileError;
class UnknownPlatformError extends Error {
    constructor(platform) {
        super(`Unknown Platform: "${platform}"`);
        this.platform = platform;
    }
}
exports.UnknownPlatformError = UnknownPlatformError;
class UnknownArchitectureError extends Error {
    constructor(arch, platform) {
        super();
        this.arch = arch;
        this.platform = platform;
        if (!utils_1.isNullOrUndefined(platform)) {
            this.message = `Unsupported Architecture-Platform combination: arch: "${arch}", platform: "${platform}"`;
        }
        else {
            this.message = `Unsupported Architecture: "${arch}"`;
        }
    }
}
exports.UnknownArchitectureError = UnknownArchitectureError;
class WaitForPrimaryTimeoutError extends Error {
    constructor(timeout) {
        super(`Timed out after ${timeout}ms while waiting for a Primary`);
        this.timeout = timeout;
    }
}
exports.WaitForPrimaryTimeoutError = WaitForPrimaryTimeoutError;
class EnsureInstanceError extends Error {
    constructor(isRunning) {
        super();
        this.isRunning = isRunning;
        const baseMesasge = '"ensureInstance" failed, because';
        if (isRunning) {
            this.message = `${baseMesasge} state was "running" but "instanceInfo" was undefined!`;
        }
        else {
            this.message = `${baseMesasge} "instanceInfo" was undefined after running "start"`;
        }
    }
}
exports.EnsureInstanceError = EnsureInstanceError;
class NoSystemBinaryFoundError extends Error {
    constructor(binaryPath) {
        super(`Config option "SYSTEM_BINARY" was provided with value "${binaryPath}", but no binary could be found!`);
        this.binaryPath = binaryPath;
    }
}
exports.NoSystemBinaryFoundError = NoSystemBinaryFoundError;
class Md5CheckFailedError extends Error {
    constructor(binarymd5, checkfilemd5) {
        super(`MD5 check failed! Binary MD5 is "${binarymd5}", Checkfile MD5 is "${checkfilemd5}"`);
        this.binarymd5 = binarymd5;
        this.checkfilemd5 = checkfilemd5;
    }
}
exports.Md5CheckFailedError = Md5CheckFailedError;
class StartBinaryFailedError extends Error {
    constructor(binary) {
        super(`Starting the Binary Failed (PID is undefined)! Binary: "${binary}"`);
        this.binary = binary;
    }
}
exports.StartBinaryFailedError = StartBinaryFailedError;
//# sourceMappingURL=errors.js.map